import configparser
import os

class Configuration:
    def __init__(self, file_path):
        self.file_path = file_path
        self.config = configparser.ConfigParser()
        self.load_settings()

    def load_settings(self):
        """Load settings from the INI file."""
        if os.path.exists(self.file_path):
            self.config.read(self.file_path)

    def store_settings(self, section, settings):
        """Store settings to the INI file."""
        if not self.config.has_section(section):
            self.config.add_section(section)
        for key, value in settings.items():
            self.config.set(section, key, str(value))
        with open(self.file_path, 'w') as file:
            self.config.write(file)

    def modify_setting(self, section, key, value):
        """Modify a specific setting in the INI file."""
        if not self.config.has_section(section):
            self.config.add_section(section)
        self.config.set(section, key, str(value))
        with open(self.file_path, 'w') as file:
            self.config.write(file)

    def get_setting(self, section, key, default=None):
        """Get a specific setting from the INI file."""
        if self.config.has_section(section) and self.config.has_option(section, key):
            return self.config.get(section, key)
        return default


from setuptools import setup, find_packages

setup(
    name='ArtexConfigure',
    version='0.0.1',
    author='Artex AI',
    description='A python library that writes your configuration into an .ini file',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/JunaidParkar/ArtexConfigure',
    include_package_data=True,
    packages=find_packages(),
    install_requires=[
        'configparser'
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Boost Software License 1.0 (BSL-1.0)',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    project_urls={
        'Documentation': 'https://github.com/JunaidParkar/ArtexConfigure',
        'Source': 'https://github.com/JunaidParkar/ArtexConfigure',
        'Tracker': 'https://github.com/JunaidParkar/ArtexConfigure',
    },
)